@@ -5,22 +5,18 @@
 ;;
 ;; This file is part of guile-json.
 ;;
-;; guile-json is free software; you can redistribute it and/or
-;; modify it under the terms of the GNU General Public License and
-;; the GNU Lesser General Public License as published by the Free
-;; Software Foundation; either version 3 of the License, or (at your
-;; option) any later version.
+;; guile-json is free software: you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 3 of the License, or
+;; (at your option) any later version.
 ;;
-;; guile-json is distributed in the hope that it will be useful,
-;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-;; General Public License and the GNU Lesser General Public License
-;; for more details.
+;; guile-json is distributed in the hope that it will be useful, but
+;; WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+;; General Public License for more details.
 ;;
 ;; You should have received a copy of the GNU General Public License
-;; and the GNU Lesser General Public License along with guile-json;
-;; if not, write to the Free Software Foundation, Inc.,
-;; 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+;; along with guile-json. If not, see https://www.gnu.org/licenses/.
 
 ;;; Commentary:
 
@@ -130,13 +126,6 @@
 (define (atom? x)
   (or (char? x) (number? x) (string? x) (symbol? x)))
 
-(define (json-alist? x)
-  (and (pair? x)
-       (let loop ((x x))
-         (or (null? x)
-             (and (pair? (car x)) (atom? (caar x))
-                  (loop (cdr x)))))))
-
 (define (json-build-string scm port escape)
   (display "\"" port)
   (display
@@ -191,7 +180,6 @@
    ((number? scm) (json-build-number scm port))
    ((symbol? scm) (json-build-string (symbol->string scm) port escape))
    ((string? scm) (json-build-string scm port escape))
-   ((json-alist? scm) (json-build-object scm port escape pretty level))
    ((list? scm) (json-build-array scm port escape pretty level))
    ((hash-table? scm)
     (json-build-object (hash-map->list cons scm) port escape pretty level))
